==> trircd-release-5.1.7-r.tar.gz: trircd-release-5.1.7-r/modules/m_userip.c <==
/************************************************************************
 *   IRC - Internet Relay Chat, modules/m_userhost.c
 *
 *   Copyright (C) 2000-2002 TR-IRCD Development
 *
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Co Center
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers.
 *
 *   This program is free softwmare; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "struct.h"
#include "common.h"
#include "sys.h"
#include "h.h"
#include "msg.h"
#include "s_conf.h"
#include "numeric.h"
#include "language.h"

static char buf[BUFSIZE], buf2[BUFSIZE];

static struct Message _msgtab[] = {
    {MSG_USERIP, 0, 1, M_SLOW, 0L,
     m_unregistered, m_permission, m_userip, m_ignore, m_userip}
};

#ifndef STATIC_MODULES

char *_version = "$Revision: 5.6 $";

void _modinit(void)
{
    mod_add_cmd(_msgtab);
}

void _moddeinit(void)
{
    mod_del_cmd(_msgtab);
}
#else
void m_userip_init(void)
{
    mod_add_cmd(_msgtab);
}
#endif

int m_userip(aClient *cptr, aClient *sptr, int parc, char *parv[])
{
    char *p = NULL;
    aClient *acptr;
    char *s;
    int i, len;

    if (parc > 2)
	(void) m_userip(cptr, sptr, parc - 1, parv + 1);

    if (parc < 2) {
	send_me_numeric(sptr, ERR_NEEDMOREPARAMS, MSG_USERIP);
	return 0;
    }

    (void) ircsprintf(buf, rpl_str(RPL_USERIP), &me, parv[0]);
    len = strlen(buf);
    *buf2 = '\0';
    logevent_call(LogSys.operevent, MSG_USERIP, sptr, &parv, parc);
    for (i = 5, s = strtoken(&p, parv[1], " "); i && s; s = strtoken(&p, (char *) NULL, " "), i--)
	if ((acptr = find_person(s))) {

	    if (!IN_ADDR(acptr->ip)) {
		send_me_numeric(sptr, ERR_OLDSERVER, acptr->name);
		continue;
	    }

	    if (*buf2)
		(void) strcat(buf, " ");

	    (void) ircsprintf(buf2, "%s%s=%c%s@%s",
			      acptr->name,
			      IsAnOper(acptr) ? "*" : "",
			      (acptr->user->away) ? '-' : '+',
			      acptr->user->username, 
			      (IsClientIpv6(acptr) ? acptr->hostip : inetntoa((char *) &IN_ADDR(acptr->ip)))
		);
	    (void) strncat(buf, buf2, sizeof(buf) - len);
	    len += strlen(buf2);
	}
    sendto_one(sptr, "%s", buf);
    return 0;
}

==> trircd-release-5.7.3-r.tar.gz: trircd-release-5.7.3-r/modules/m_userip.c <==
/************************************************************************
 *   IRC - Internet Relay Chat, modules/m_userhost.c
 *
 *   Copyright (C) 2000-2003 TR-IRCD Development
 *
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Co Center
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers.
 *
 *   This program is free softwmare; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "struct.h"
#include "common.h"
#include "sys.h"
#include "h.h"
#include "msg.h"
#include "numeric.h"
#include "s_conf.h"
#include "language.h"

static char buf[BUFSIZE], buf2[BUFSIZE];

static struct Message _msgtab[] = {
    {MSG_USERIP, 0, 1, M_SLOW, 0L,
     m_unregistered, m_permission, m_userip, m_ignore, m_userip}
};

#ifndef STATIC_MODULES

char *_version = "$Revision: 1.3 $";

void _modinit(void)
{
    mod_add_cmd(_msgtab);
}

void _moddeinit(void)
{
    mod_del_cmd(_msgtab);
}
#else
void m_userip_init(void)
{
    mod_add_cmd(_msgtab);
}
#endif

int m_userip(aClient *cptr, aClient *sptr, int parc, char *parv[])
{
    char *p = NULL;
    aClient *acptr;
    char *s;
    int i, len;

    if (!IsSeeHidden(sptr))
	return m_permission(sptr, cptr, parc, parv);

    if (parc > 2)
	m_userip(cptr, sptr, parc - 1, parv + 1);

    if (parc < 2) {
	send_me_numeric(sptr, ERR_NEEDMOREPARAMS, MSG_USERIP);
	return 0;
    }

    ircsprintf(buf, rpl_str(RPL_USERIP), &me, parv[0]);
    len = strlen(buf);
    *buf2 = '\0';
    logevent_call(LogSys.operevent, MSG_USERIP, sptr, &parv, parc);
    for (i = 5, s = strtoken(&p, parv[1], " "); i && s; s = strtoken(&p, (char *) NULL, " "), i--)
	if ((acptr = find_person(s))) {

	    if (!IN_ADDR(acptr->ip)) {
		send_me_numeric(sptr, ERR_OLDSERVER, acptr->name);
		continue;
	    }

	    if (*buf2)
		strcat(buf, " ");

	    ircsprintf(buf2, "%s%s=%c%s@%s",
			      acptr->name,
			      IsAnOper(acptr) ? "*" : "",
			      (acptr->user->away) ? '-' : '+',
			      acptr->user->username, 
			      (IsClientIpv6(acptr) ? acptr->hostip : inetntoa((char *) &IN_ADDR(acptr->ip)))
		);
	    strncat(buf, buf2, sizeof(buf) - len);
	    len += strlen(buf2);
	}
    sendto_one(sptr, "%s", buf);
    return 0;
}
